@@ -870,7 +870,7 @@ struct activity pwr_fan_act = {
 #ifdef SOURCE_SADF
 	.f_render	= render_pwr_fan_stats,
 	.f_xml_print	= xml_print_pwr_fan_stats,
-	.hdr_line	= "device;FAN;rpm",
+	.hdr_line	= "device;FAN;rpm;drpm",
 	.name		= "A_PWR_FAN",
 #endif
 	.nr		= -1,
@@ -884,7 +884,7 @@ struct activity pwr_fan_act = {
 /* Temperature */
 struct activity pwr_temp_act = {
 	.id		= A_PWR_TEMP,
-	.options	= AO_CLOSE_MARKUP,
+	.options	= AO_NULL,
 #ifdef SOURCE_SADC
 	.f_count	= wrap_get_temp_nr,
 	.f_read		= wrap_read_temp,
@@ -896,8 +896,8 @@ struct activity pwr_temp_act = {
 #ifdef SOURCE_SADF
 	.f_render	= render_pwr_temp_stats,
 	.f_xml_print	= xml_print_pwr_temp_stats,
-	.hdr_line	= "device;ID;temp_cls",
-	.name	= "A_PWR_TEMP",
+	.hdr_line	= "device;TEMP;degC;%temp",
+	.name		= "A_PWR_TEMP",
 #endif
 	.nr		= -1,
 	.fsize		= STATS_PWR_TEMP_SIZE,
@@ -907,6 +907,33 @@ struct activity pwr_temp_act = {
 	.bitmap		= NULL
 };
 
+/* Voltage inputs */
+struct activity pwr_in_act = {
+	.id		= A_PWR_IN,
+	.options	= AO_CLOSE_MARKUP,
+#ifdef SOURCE_SADC
+	.f_count	= wrap_get_in_nr,
+	.f_read		= wrap_read_in,
+#endif
+#ifdef SOURCE_SAR
+	.f_print	= print_pwr_in_stats,
+	.f_print_avg	= print_avg_pwr_in_stats,
+#endif
+#ifdef SOURCE_SADF
+	.f_render	= render_pwr_in_stats,
+	.f_xml_print	= xml_print_pwr_in_stats,
+	.hdr_line	= "device;IN;inV;%in",
+	.name		= "A_PWR_IN",
+#endif
+	.nr		= -1,
+	.fsize		= STATS_PWR_IN_SIZE,
+	.msize		= STATS_PWR_IN_SIZE,
+	.opt_flags	= 0,
+	.buf		= {NULL, NULL, NULL},
+	.bitmap		= NULL
+};
+
+
 /*
  * Array of activities.
  */
@@ -942,5 +969,6 @@ struct activity *act[NR_ACT] = {
 	&net_udp6_act,
 	&pwr_cpufreq_act,
 	&pwr_fan_act,
-	&pwr_temp_act
+	&pwr_temp_act,
+	&pwr_in_act
 };
