@@ -1771,10 +1771,10 @@ __print_funct_t print_avg_pwr_cpufreq_stats(struct activity *a, int prev, int cu
  * instantaneous and average statistics.
  *
  * IN:
- * @a          Activity structure with statistics.
- * @prev       Index in array where stats used as reference are.
- * @curr       Index in array for current sample statistics.
- * @dispavg    True if displaying average statistics.
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @dispavg	True if displaying average statistics.
  ***************************************************************************
  */
 void stub_print_pwr_fan_stats(struct activity *a, int prev, int curr, int dispavg)
@@ -1782,34 +1782,47 @@ void stub_print_pwr_fan_stats(struct activity *a, int prev, int curr, int dispav
 	int i;
 	struct stats_pwr_fan *spc;
 	static double *avg_fan = NULL;
+	static double *avg_fan_min = NULL;
 
+	/* Allocate arrays of fan RPMs */
 	if (!avg_fan) {
-		/* Allocate array of fan RPMs */
 		if ((avg_fan = (double *) malloc(sizeof(double) * a->nr)) == NULL) {
 			perror("malloc");
 			exit(4);
 		}
 		memset(avg_fan, 0, sizeof(double) * a->nr);
 	}
+	if (!avg_fan_min) {
+		if ((avg_fan_min = (double *) malloc(sizeof(double) * a->nr)) == NULL) {
+			perror("malloc");
+			exit(4);
+		}
+		memset(avg_fan_min, 0, sizeof(double) * a->nr);
+	}
 
 	if (dis) {
-		printf("\n%-11s     FAN       rpm     %*s\n",
+		printf("\n%-11s     FAN       rpm      drpm     %*s\n",
 		       timestamp[!curr], MAX_SENSORS_DEV_LEN, "DEVICE");
 	}
 
-	for (i = 0; (i < a->nr); i++) {
+	for (i = 0; i < a->nr; i++) {
 		spc = (struct stats_pwr_fan *) ((char *) a->buf[curr] + i * a->msize);
 
 		printf("%-11s     %3d", timestamp[curr], i + 1);
 
 		if (dispavg) {
 			/* Display average values */
-			printf(" %9.2f", (double) avg_fan[i] / avg_count);
+			printf(" %9.2f %9.2f",
+			       (double) avg_fan[i] / avg_count,
+			       (double) (avg_fan[i] - avg_fan_min[i]) / avg_count);
 		}
 		else {
 			/* Display instantaneous values */
-			printf(" %9.2f", spc->rpm);
-			avg_fan[i] += spc->rpm;
+			printf(" %9.2f %9.2f",
+			       spc->rpm,
+			       spc->rpm - spc->rpm_min);
+			avg_fan[i]     += spc->rpm;
+			avg_fan_min[i] += spc->rpm_min;
 		}
 
 		printf("     %*s\n", MAX_SENSORS_DEV_LEN, spc->device);
@@ -1820,6 +1833,10 @@ void stub_print_pwr_fan_stats(struct activity *a, int prev, int curr, int dispav
 			free(avg_fan);
 			avg_fan = NULL;
 		}
+		if (avg_fan_min) {
+			free(avg_fan_min);
+			avg_fan_min = NULL;
+		}
 	}
 }
 
@@ -1828,10 +1845,10 @@ void stub_print_pwr_fan_stats(struct activity *a, int prev, int curr, int dispav
  * Display fan statistics.
  *
  * IN:
- * @a          Activity structure with statistics.
- * @prev       Index in array where stats used as reference are.
- * @curr       Index in array for current sample statistics.
- * @itv                Interval of time in jiffies.
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in jiffies.
  ***************************************************************************
  */
 __print_funct_t print_pwr_fan_stats(struct activity *a, int prev, int curr,
@@ -1845,14 +1862,14 @@ __print_funct_t print_pwr_fan_stats(struct activity *a, int prev, int curr,
  * Display average fan statistics.
  *
  * IN:
- * @a          Activity structure with statistics.
- * @prev       Index in array where stats used as reference are.
- * @curr       Index in array for current sample statistics.
- * @itv                Interval of time in jiffies.
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in jiffies.
  ***************************************************************************
  */
 __print_funct_t print_avg_pwr_fan_stats(struct activity *a, int prev, int curr,
-                                       unsigned long long itv)
+					unsigned long long itv)
 {
 	stub_print_pwr_fan_stats(a, prev, curr, TRUE);
 }
@@ -1863,10 +1880,10 @@ __print_funct_t print_avg_pwr_fan_stats(struct activity *a, int prev, int curr,
  * instantaneous and average statistics.
  *
  * IN:
- * @a          Activity structure with statistics.
- * @prev       Index in array where stats used as reference are.
- * @curr       Index in array for current sample statistics.
- * @dispavg    True if displaying average statistics.
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @dispavg	True if displaying average statistics.
  ***************************************************************************
  */
 void stub_print_pwr_temp_stats(struct activity *a, int prev, int curr, int dispavg)
@@ -1874,34 +1891,60 @@ void stub_print_pwr_temp_stats(struct activity *a, int prev, int curr, int dispa
 	int i;
 	struct stats_pwr_temp *spc;
 	static double *avg_temp = NULL;
+	static double *avg_temp_min = NULL, *avg_temp_max = NULL;
 
+	/* Allocate arrays of temperatures */
 	if (!avg_temp) {
-		/* Allocate array of temperatures */
 		if ((avg_temp = (double *) malloc(sizeof(double) * a->nr)) == NULL) {
 			perror("malloc");
 			exit(4);
 		}
 		memset(avg_temp, 0, sizeof(double) * a->nr);
 	}
+	if (!avg_temp_min) {
+		if ((avg_temp_min = (double *) malloc(sizeof(double) * a->nr)) == NULL) {
+			perror("malloc");
+			exit(4);
+		}
+		memset(avg_temp_min, 0, sizeof(double) * a->nr);
+	}
+	if (!avg_temp_max) {
+		if ((avg_temp_max = (double *) malloc(sizeof(double) * a->nr)) == NULL) {
+			perror("malloc");
+			exit(4);
+		}
+		memset(avg_temp_max, 0, sizeof(double) * a->nr);
+	}
 
 	if (dis) {
-		printf("\n%-11s      ID  temp_cls     %*s\n",
+		printf("\n%-11s    TEMP      degC     %%temp     %*s\n",
 		       timestamp[!curr], MAX_SENSORS_DEV_LEN, "DEVICE");
 	}
 
-	for (i = 0; (i < a->nr); i++) {
+	for (i = 0; i < a->nr; i++) {
 		spc = (struct stats_pwr_temp *) ((char *) a->buf[curr] + i * a->msize);
 
 		printf("%-11s     %3d", timestamp[curr], i + 1);
 
 		if (dispavg) {
 			/* Display average values */
-			printf(" %9.2f", (double) avg_temp[i] / avg_count);
+			printf(" %9.2f %9.2f",
+			       (double) avg_temp[i] / avg_count,
+			       (avg_temp_max[i] - avg_temp_min[i]) ?
+			       ((double) (avg_temp[i] / avg_count) - avg_temp_min[i]) / (avg_temp_max[i] - avg_temp_min[i]) * 100 :
+			       0.0);
 		}
 		else {
 			/* Display instantaneous values */
-			printf(" %9.2f", spc->temp);
+			printf(" %9.2f %9.2f",
+			       spc->temp,
+			       (spc->temp_max - spc->temp_min) ?
+			       (spc->temp - spc->temp_min) / (spc->temp_max - spc->temp_min) * 100 :
+			       0.0);
 			avg_temp[i] += spc->temp;
+			/* Assume that min and max temperatures cannot vary */
+			avg_temp_min[i] = spc->temp_min;
+			avg_temp_max[i] = spc->temp_max;
 		}
 		
 		printf("     %*s\n", MAX_SENSORS_DEV_LEN, spc->device);
@@ -1912,6 +1955,14 @@ void stub_print_pwr_temp_stats(struct activity *a, int prev, int curr, int dispa
 			free(avg_temp);
 			avg_temp = NULL;
 		}
+		if (avg_temp_min) {
+			free(avg_temp_min);
+			avg_temp_min = NULL;
+		}
+		if (avg_temp_max) {
+			free(avg_temp_max);
+			avg_temp_max = NULL;
+		}
 	}
 }
 
@@ -1920,14 +1971,14 @@ void stub_print_pwr_temp_stats(struct activity *a, int prev, int curr, int dispa
  * Display temperature statistics.
  *
  * IN:
- * @a          Activity structure with statistics.
- * @prev       Index in array where stats used as reference are.
- * @curr       Index in array for current sample statistics.
- * @itv                Interval of time in jiffies.
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in jiffies.
  ***************************************************************************
  */
 __print_funct_t print_pwr_temp_stats(struct activity *a, int prev, int curr,
-                                       unsigned long long itv)
+				     unsigned long long itv)
 {
 	stub_print_pwr_temp_stats(a, prev, curr, FALSE);
 }
@@ -1937,14 +1988,140 @@ __print_funct_t print_pwr_temp_stats(struct activity *a, int prev, int curr,
  * Display average temperature statistics.
  *
  * IN:
- * @a          Activity structure with statistics.
- * @prev       Index in array where stats used as reference are.
- * @curr       Index in array for current sample statistics.
- * @itv                Interval of time in jiffies.
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in jiffies.
  ***************************************************************************
  */
 __print_funct_t print_avg_pwr_temp_stats(struct activity *a, int prev, int curr,
-                                       unsigned long long itv)
+					 unsigned long long itv)
 {
 	stub_print_pwr_temp_stats(a, prev, curr, TRUE);
 }
+
+/*
+ ***************************************************************************
+ * Display voltage inputs statistics. This function is used to display
+ * instantaneous and average statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @dispavg	True if displaying average statistics.
+ ***************************************************************************
+ */
+void stub_print_pwr_in_stats(struct activity *a, int prev, int curr, int dispavg)
+{
+	int i;
+	struct stats_pwr_in *spc;
+	static double *avg_in = NULL;
+	static double *avg_in_min = NULL, *avg_in_max = NULL;
+
+	/* Allocate arrays of voltage inputs */
+	if (!avg_in) {
+		if ((avg_in = (double *) malloc(sizeof(double) * a->nr)) == NULL) {
+			perror("malloc");
+			exit(4);
+		}
+		memset(avg_in, 0, sizeof(double) * a->nr);
+	}
+	if (!avg_in_min) {
+		if ((avg_in_min = (double *) malloc(sizeof(double) * a->nr)) == NULL) {
+			perror("malloc");
+			exit(4);
+		}
+		memset(avg_in_min, 0, sizeof(double) * a->nr);
+	}
+	if (!avg_in_max) {
+		if ((avg_in_max = (double *) malloc(sizeof(double) * a->nr)) == NULL) {
+			perror("malloc");
+			exit(4);
+		}
+		memset(avg_in_max, 0, sizeof(double) * a->nr);
+	}
+
+	if (dis) {
+		printf("\n%-11s      IN       inV       %%in     %*s\n",
+		       timestamp[!curr], MAX_SENSORS_DEV_LEN, "DEVICE");
+	}
+
+	for (i = 0; i < a->nr; i++) {
+		spc = (struct stats_pwr_in *) ((char *) a->buf[curr] + i * a->msize);
+
+		printf("%-11s     %3d", timestamp[curr], i);
+
+		if (dispavg) {
+			/* Display average values */
+			printf(" %9.2f %9.2f",
+			       (double) avg_in[i] / avg_count,
+			       (avg_in_max[i] - avg_in_min[i]) ?
+			       ((double) (avg_in[i] / avg_count) - avg_in_min[i]) / (avg_in_max[i] - avg_in_min[i]) * 100 :
+			       0.0);
+		}
+		else {
+			/* Display instantaneous values */
+			printf(" %9.2f %9.2f",
+			       spc->in,
+			       (spc->in_max - spc->in_min) ?
+			       (spc->in - spc->in_min) / (spc->in_max - spc->in_min) * 100 :
+			       0.0);
+			avg_in[i] += spc->in;
+			/* Assume that min and max voltage inputs cannot vary */
+			avg_in_min[i] = spc->in_min;
+			avg_in_max[i] = spc->in_max;
+		}
+
+		printf("     %*s\n", MAX_SENSORS_DEV_LEN, spc->device);
+	}
+
+	if (dispavg) {
+		if (avg_in) {
+			free(avg_in);
+			avg_in = NULL;
+		}
+		if (avg_in_min) {
+			free(avg_in_min);
+			avg_in_min = NULL;
+		}
+		if (avg_in_max) {
+			free(avg_in_max);
+			avg_in_max = NULL;
+		}
+	}
+}
+
+/*
+ ***************************************************************************
+ * Display voltage inputs statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in jiffies.
+ ***************************************************************************
+ */
+__print_funct_t print_pwr_in_stats(struct activity *a, int prev, int curr,
+				   unsigned long long itv)
+{
+	stub_print_pwr_in_stats(a, prev, curr, FALSE);
+}
+
+/*
+ ***************************************************************************
+ * Display average voltage inputs statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @prev	Index in array where stats used as reference are.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in jiffies.
+ ***************************************************************************
+ */
+__print_funct_t print_avg_pwr_in_stats(struct activity *a, int prev, int curr,
+				       unsigned long long itv)
+{
+	stub_print_pwr_in_stats(a, prev, curr, TRUE);
+}
