@@ -107,6 +107,8 @@ extern __print_funct_t render_pwr_fan_stats
 	(struct activity *, int, char *, int, unsigned long long);
 extern __print_funct_t render_pwr_temp_stats
 	(struct activity *, int, char *, int, unsigned long long);
+extern __print_funct_t render_pwr_in_stats
+	(struct activity *, int, char *, int, unsigned long long);
 
 /* Functions used to display statistics in XML */
 extern void xprintf
@@ -175,5 +177,7 @@ extern __print_funct_t xml_print_pwr_fan_stats
 	(struct activity *, int, int, unsigned long long);
 extern __print_funct_t xml_print_pwr_temp_stats
 	(struct activity *, int, int, unsigned long long);
+extern __print_funct_t xml_print_pwr_in_stats
+	(struct activity *, int, int, unsigned long long);
 
 #endif /* _PRF_STATS_H */
