@@ -1,6 +1,6 @@
 /*
  * rd_stats.h: Include file used to read system statistics
- * (C) 1999-2009 by Sebastien Godard (sysstat <at> orange.fr)
+ * (C) 1999-2010 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _RD_STATS_H
@@ -481,6 +481,41 @@ struct stats_pwr_cpufreq {
 
 #define STATS_PWR_CPUFREQ_SIZE	(sizeof(struct stats_pwr_cpufreq))
 
+/*
+ * Structure for fan statistics.
+ */
+struct stats_pwr_fan {
+	double  rpm				__attribute__ ((aligned (8)));
+	double  rpm_min				__attribute__ ((aligned (8)));
+	char    device[MAX_SENSORS_DEV_LEN]	__attribute__ ((aligned (8)));
+};
+
+#define STATS_PWR_FAN_SIZE     (sizeof(struct stats_pwr_fan))
+
+/*
+ * Structure for device temperature statistics.
+ */
+struct stats_pwr_temp {
+	double  temp				__attribute__ ((aligned (8)));
+	double  temp_min			__attribute__ ((aligned (8)));
+	double  temp_max			__attribute__ ((aligned (8)));
+	char    device[MAX_SENSORS_DEV_LEN]	__attribute__ ((aligned (8)));
+};
+
+#define STATS_PWR_TEMP_SIZE    (sizeof(struct stats_pwr_temp))
+
+/*
+ * Structure for voltage inputs statistics.
+ */
+struct stats_pwr_in {
+	double  in				__attribute__ ((aligned (8)));
+	double  in_min				__attribute__ ((aligned (8)));
+	double  in_max				__attribute__ ((aligned (8)));
+	char    device[MAX_SENSORS_DEV_LEN]	__attribute__ ((aligned (8)));
+};
+
+#define STATS_PWR_IN_SIZE    (sizeof(struct stats_pwr_in))
+
 /*
  ***************************************************************************
  * Prototypes for functions used to read system statistics
@@ -550,6 +585,12 @@ extern void
 	read_net_udp6(struct stats_net_udp6 *);
 extern void
 	read_cpuinfo(struct stats_pwr_cpufreq *, int);
+extern void
+	read_fan(struct stats_pwr_fan *, int);
+extern void
+	read_temp(struct stats_pwr_temp *, int);
+extern void
+	read_in(struct stats_pwr_in *, int);
 
 /*
  ***************************************************************************
@@ -571,6 +612,11 @@ extern int
 	get_cpu_nr(unsigned int);
 extern int
 	get_irqcpu_nr(char *, int, int);
-
+extern int
+	get_fan_nr(void);
+extern int
+	get_temp_nr(void);
+extern int
+	get_in_nr(void);
 
 #endif /* _RD_STATS_H */
