@@ -17,7 +17,7 @@
  */
 
 /* Number of activities */
-#define NR_ACT	32
+#define NR_ACT	33
 
 /* Activities */
 #define A_CPU		1
@@ -52,6 +52,7 @@
 #define A_PWR_CPUFREQ	30
 #define A_PWR_FAN	31
 #define A_PWR_TEMP	32
+#define A_PWR_IN	33
 
 
 /* Macro used to flag an activity that should be collected */
@@ -150,6 +151,7 @@
 #define K_CPU		"CPU"
 #define K_FAN		"FAN"
 #define K_TEMP		"TEMP"
+#define K_IN		"IN"
 
 /* sadc program */
 #define SADC		"sadc"
@@ -609,6 +611,8 @@ extern __nr_t
 	wrap_get_fan_nr(struct activity *);
 extern __nr_t
 	wrap_get_temp_nr(struct activity *);
+extern __nr_t
+	wrap_get_in_nr(struct activity *);
 
 /* Functions used to read activities statistics */
 extern __read_funct_t
@@ -675,6 +679,8 @@ extern __read_funct_t
 	wrap_read_fan(struct activity *);
 extern __read_funct_t
 	wrap_read_temp(struct activity *);
+extern __read_funct_t
+	wrap_read_in(struct activity *);
 
 /* Other functions */
 extern void
