@@ -805,7 +805,7 @@ __read_funct_t wrap_read_cpuinfo(struct activity *a)
  * @a  Activity structure.
  *
  * RETURNS:
- * Number of structures
+ * Number of structures.
  ***************************************************************************
  */
 __nr_t wrap_get_fan_nr(struct activity *a)
@@ -843,12 +843,12 @@ __read_funct_t wrap_read_fan(struct activity *a)
  * @a  Activity structure.
  *
  * RETURNS:
- * Number of structures
+ * Number of structures.
  ***************************************************************************
  */
 __nr_t wrap_get_temp_nr(struct activity *a)
 {
-return (get_temp_nr());
+	return (get_temp_nr());
 }
 
 /*
@@ -872,3 +872,41 @@ __read_funct_t wrap_read_temp(struct activity *a)
 
 	return;
 }
+
+/*
+ ***************************************************************************
+ * Get number of voltage input structures to allocate.
+ *
+ * IN:
+ * @a  Activity structure.
+ *
+ * RETURNS:
+ * Number of structures.
+ ***************************************************************************
+ */
+__nr_t wrap_get_in_nr(struct activity *a)
+{
+	return (get_in_nr());
+}
+
+/*
+ ***************************************************************************
+ * Read voltage input statistics.
+ *
+ * IN:
+ * @a  Activity structure.
+ *
+ * OUT:
+ * @a  Activity structure with statistics.
+ ***************************************************************************
+ */
+__read_funct_t wrap_read_in(struct activity *a)
+{
+	struct stats_pwr_in *st_pwr_in
+		= (struct stats_pwr_in *) a->_buf0;
+
+	/* Read voltage input stats */
+	read_in(st_pwr_in, a->nr);
+
+	return;
+}
