@@ -1,6 +1,6 @@
 /*
  * sadc: system activity data collector
- * (C) 1999-2009 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2010 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -47,6 +47,11 @@
 #define _(string) (string)
 #endif
 
+#ifdef HAVE_SENSORS
+#include "sensors/sensors.h"
+#include "sensors/error.h"
+#endif
+
 #define SCCSID "@(#)sysstat-" VERSION ": " __FILE__ " compiled " __DATE__ " " __TIME__
 char *sccsid(void) { return (SCCSID); }
 
@@ -133,6 +138,8 @@ void parse_sadc_S_option(char *argv[], int opt)
 		else if (!strcmp(p, K_POWER)) {
 			/* Select activities related to power management */
 			COLLECT_ACTIVITY(A_PWR_CPUFREQ);
+			COLLECT_ACTIVITY(A_PWR_FAN);
+			COLLECT_ACTIVITY(A_PWR_TEMP);
 		}
 		else if (!strcmp(p, K_ALL) || !strcmp(p, K_XALL)) {
 			/* Select all activities */
@@ -940,6 +947,14 @@ int main(int argc, char **argv)
 
 	ofile[0] = comment[0] = '\0';
 
+#ifdef HAVE_SENSORS
+	/* Initialize sensors, let it use the default cfg file */
+	int err = sensors_init(NULL);
+	if (err) {
+		fprintf(stderr, "sensors_init: %s\n", sensors_strerror(err));
+	}
+#endif /* HAVE_SENSORS */
+	
 #ifdef USE_NLS
 	/* Init National Language Support */
 	init_nls();
@@ -1088,6 +1103,11 @@ int main(int argc, char **argv)
 	/* Main loop */
 	rw_sa_stat_loop(count, &rectime, stdfd, ofd, ofile);
 
+#ifdef HAVE_SENSORS
+	/* Cleanup sensors */
+	sensors_cleanup();
+#endif /* HAVE_SENSORS */
+
 	/* Free structures */
 	sa_sys_free();
 
